


###############################
#load("parte_1.Rdata")
###############################


install.packages(c("ape","geiger","phylotools","adephylo","Hmisc",
                   "RRphylo", "devtools", "ape", "rlg","phyloextra",
                   "nlme","picante","SYNCSA", "MuMIn", "TreeSim",
                   "diversitree","RPANDA","PCPS","maptools","rgdal",
                   "ggplot2","wesanderson","RColorBrewer","graphics",
                   "matlab","gmt","letsR","sf","lavaan","semPlot",
                   "qpcR","semTools"))



#Pacotes necessarios
library(ape)
library(geiger)
library(phylotools)
library(adephylo)
library(Hmisc)
library(rgl)
library(RRphylo)
library(devtools)
install_github("liamrevell/phytools")
library(phytools)

library(nlme)
library(picante)
library(SYNCSA)
library(MuMIn)
library(TreeSim)
library(diversitree)
library(RPANDA)




#######################################################################
#Ler filogenia canidae


tree=read.tree("phylo_canidae.new")

plot(tree)

axisPhylo(side = 1, root.time = NULL, backward = TRUE)



#######################################################################
##LENDO OS DADOS

dados<-read.table("canidae_traits.txt",h=T,row.names=1)
head(dados)


match.species<-treedata(tree,dados)
tree<-match.species$phy
plotTree(tree,fsize=0.5,ftype="i",type="fan",lwd=1)


#######################################################################
## RECOSNTRUÇÃO TRAIT CONTINUO

tamanho<-log(dados$TAMANHO)
names(tamanho)=rownames(dados)
tamanho

set.seed(13)

obj<-contMap(tree,tamanho,plot=FALSE)

contMap_tamanho<-setMap(obj,hcl.colors(10,
                                   palette="Spectral",rev=TRUE))

dev.off()

plot(contMap_tamanho,legend=0.6 *max(nodeHeights(tree)),
     fsize=c(0.7,0.8),invert=TRUE)


#aumento de tamanho ocorreu no lobo guará de forma independente 
#tivemos dois eventos de redução de tamanho, sendo um no clado das raposas 
#e o outro na América do Sul no gênero Lycalopex

dev.off()


###projetando os dados no espaco filogenetico 
phenogram(tree,tamanho,fsize=0.6,spread.costs=c(1,0))




#######################################################################
# identificando locais de maior incerteza

dev.off()

fancyTree(tree,type="phenogram95",x=tamanho,spread.cost=c(1,0))
#pode levar alguns minutos 


#podemos compensar com dados faltantes inserindo nos nodes da filogenia 


#######################################################################
## RECOSNTRUÇÃO TRAIT CATEGORICO 

#3= hipercanivoro
#2= mesocarnivoro
#1= hipocarnivoro

dieta_cat<-dados$DIETA_CATEGORIA
names(dieta_cat)=rownames(dados)
dieta_cat


plotTree(tree,fsize=0.7,ftype="i")

#clicar onde quer a legenda

cols<-setNames(palette()[1:length(unique(dieta_cat))],sort(unique(dieta_cat)))
tiplabels(pie=to.matrix(dieta_cat,sort(unique(dieta_cat))),piecol=cols,cex=0.2)
add.simmap.legend(colors=cols,prompt=T,x=0.2,
                  y=-max(nodeHeights(tree)),fsize=0.8)

set.seed(13)

## estimate ancestral states 
fitER<-ace(dieta_cat,tree,model="ER",type="discrete")
fitER


plotTree(tree,fsize=0.7,ftype="i")

#clicar onde quer a legenda

nodelabels(node=1:tree$Nnode+Ntip(tree),
           pie=fitER$lik.anc,piecol=cols,cex=0.5)
tiplabels(pie=to.matrix(dieta_cat,sort(unique(dieta_cat))),piecol=cols,cex=0.3)
add.simmap.legend(colors=cols,prompt=T,x=0.2,
                  y=-max(nodeHeights(tree)),fsize=0.8)


#######################################################################
#deixando mais complexo fazendo com 100 arvores e tirando media 

set.seed(13)

mtrees<-make.simmap(tree,dieta_cat,model="ER",nsim=100)

par(mfrow=c(10,10))
null<-sapply(mtrees,plot,colors=cols,lwd=1,ftype="off")


pd<-summary(mtrees,plot=FALSE)
pd

# Limpe a janela de plots
dev.off()

plot(pd,fsize=0.6,ftype="i")

add.simmap.legend(colors=cols,prompt=T,x=0.2,
                  y=-max(nodeHeights(tree)),fsize=0.8)

#clicar onde quer a legenda




#######################################################################
#phylomorfoespaco - vizualizacao em duas ou mais dimensoes 

#vamos criar uma subtabela com 3 atributos
#tamanho corportal 
#Cobertura vegetal 
#Dieta 


data_test=data.frame(dados[1],dados[2], dados[4])
data_test

#limpar janela de plot
dev.off()

#aqui vamos fazer apenas com tamanho corporal e habitat (duas dimensoes)
phylomorphospace(tree,data_test[,c(1,2)],xlab="Tamanho",ylab="Habitat", fsize=0.7)


#agora podemos fazer com 3 dimesoes uma versao animada 
phylomorphospace3d(tree,data_test,method = "dynamic", fsize=0.1)




#######################################################################
#evolucao espelhada entre Tamanho e Habitat
dev.off()
par(mfrow=c(1,2))


####reconstruindo a tamanho corporal
tamanho<-dados$TAMANHO
names(tamanho)=rownames(dados)
tamanho

set.seed(13)

obj<-contMap(tree,tamanho,plot=FALSE)

contMap_tamanho<-setMap(obj,hcl.colors(10,
                                     palette="Spectral",rev=TRUE))


plot(contMap_tamanho,legend=0.6 *max(nodeHeights(tree)),
     fsize=c(0.7,0.8),invert=TRUE)


######agora reconstruimos o habitat, mas mudamos a orientacao do plot 

habitat<-dados$HABITAT
names(habitat)=rownames(dados)
habitat

set.seed(13)

obj<-contMap(tree,habitat,plot=FALSE)

contMap_habitat<-setMap(obj,hcl.colors(10,
                                     palette="Spectral",rev=TRUE))


plot(contMap_habitat,legend=0.6 *max(nodeHeights(tree)),
     fsize=c(0.7,0.8),invert=TRUE, direction="leftwards")





#######################################################################
#evolucao espelhada entre tamanho e longevidade 

dev.off()
par(mfrow=c(1,2))


####reconstruindo a longevidade
longevidade<-log(dados$LONGEVIDADE)
names(longevidade)=rownames(dados)
longevidade

set.seed(13)

obj<-contMap(tree,longevidade,plot=FALSE)

contMap_longevidade<-setMap(obj,hcl.colors(10,
                                     palette="Spectral",rev=TRUE))


plot(contMap_longevidade,legend=0.6 *max(nodeHeights(tree)),
     fsize=c(0.7,0.8),invert=TRUE)


######agora reconstruimos o tamanho 

tamanho<-dados$TAMANHO
names(tamanho)=rownames(dados)
tamanho

set.seed(13)

obj<-contMap(tree,tamanho,plot=FALSE)

contMap_tamanho<-setMap(obj,hcl.colors(10,
                                       palette="Spectral",rev=TRUE))


plot(contMap_tamanho,legend=0.6 *max(nodeHeights(tree)),
     fsize=c(0.7,0.8),invert=TRUE, direction="leftwards")



#######################################################################
#######################################################################
#############                                                 #########
#############  CORRELACAO DE ATRIBUTO - MODELOS EVOLUTIVOS    ######### 
#############   considerar a nao independencia entre sps      #########
#############                                                 #########
#######################################################################
#######################################################################


#atributos entre especies irmas nao sao independentes
#pgls corrige isso

#--------------------------------------------------------------------------------------------------
##PGLS   Tamanho X Longevidade
#--------------------------------------------------------------------------------------------------

dev.off()

##corBrowniano 
tamanho_x_longevidade_brow<- gls(tamanho ~ longevidade, correlation = corBrownian(phy = tree),
                        data = dados, method = "ML")
summary(tamanho_x_longevidade_brow)
coef(tamanho_x_longevidade_brow)
str(tamanho_x_longevidade_brow) 
plot(tamanho ~ longevidade,pch=19)
abline(a = coef(tamanho_x_longevidade_brow)[1], b = coef(tamanho_x_longevidade_brow)[2], col=c("red")) 



##corMartins - OU
tamanho_x_longevidade_ou <- gls(tamanho ~ longevidade, correlation=corMartins(value=1,phy=tree),
                       data = dados, method = "ML")
summary(tamanho_x_longevidade_ou)
coef(tamanho_x_longevidade_ou)
plot(tamanho ~ longevidade,pch=19)
abline(a = coef(tamanho_x_longevidade_ou)[1], b = coef(tamanho_x_longevidade_ou)[2], col=c("red")) 




##corBlomberg - ACDC
tamanho_x_longevidade_blomberg <- gls(tamanho ~ longevidade,correlation= corBlomberg ( fixed = T,value=0.5,phy=tree),
                             data = dados, method = "ML")
summary(tamanho_x_longevidade_blomberg)
coef(tamanho_x_longevidade_blomberg)
plot(tamanho ~ longevidade,pch=19)
abline(a = coef(tamanho_x_longevidade_blomberg)[1], b = coef(tamanho_x_longevidade_blomberg)[2], col=c("red")) 



####SELECAO DOS MODELOS DE PGLS 
best_model <- (msAICc <- model.sel(tamanho_x_longevidade_blomberg,
                                   tamanho_x_longevidade_ou,
                                   tamanho_x_longevidade_brow))
best_model




#######################################################################
#######################################################################
#############                                                 #########
#############           EXPLORAR DADOS DA FILOGENIA           #########
#############                                                 #########
#######################################################################
#######################################################################


##LTT plots (lineages through time)

ltt(tree)


##podemos ver as linhagens separadas para cada estado de atributo 

#vamos separar todas as especies de acordo com suas socialidades (categoricas)

especies_solitarias=c("Lycalopex_vetulus",                           
                     "Lycalopex_sechurae",                          
                     "Lycalopex_gymnocercus",                       
                     "Lycalopex_culpaeus",                          
                     "Lycalopex_fulvipes",                          
                     "Lycalopex_griseus",                           
                     "Cerdocyon_thous",                             
                     "Atelocynus_microtis",                         
                     "Chrysocyon_brachyurus",                       
                     "Vulpes_ferrilata",                            
                     "Vulpes_velox",                                
                     "Vulpes_chama",                                
                     "Vulpes_bengalensis",                          
                     "Vulpes_cana",                                 
                     "Nyctereutes_procyonoides",                    
                     "Urocyon_littoralis",                          
                     "Urocyon_cinereoargenteus")


especies_socialidade_media=c("Canis_adustus",                               
                            "Speothos_venaticus",                          
                            "Vulpes_rueppellii",                           
                            "Vulpes_vulpes",                               
                            "Vulpes_corsac",                               
                            "Vulpes_macrotis",                             
                            "Vulpes_lagopus",                              
                            "Vulpes_pallida",                              
                            "Vulpes_zerda",                                
                            "Otocyon_megalotis")


especies_sociais=c("Canis_lupus",                                
                   "Canis_anthus",                                
                   "Canis_aureus",                                
                   "Canis_simensis",                              
                   "Canis_rufus",                                 
                   "Canis_latrans",                               
                   "Cuon_alpinus",                                
                   "Lycaon_pictus",                               
                   "Canis_mesomelas")




#filogenia especies solitarias
comparison_solitarias<-name.check(tree,especies_solitarias,data.names=especies_solitarias)
comparison_solitarias
comparison_solitarias$tree_not_data
tree_solitarias<-drop.tip(tree,comparison_solitarias$tree_not_data)
tree_solitarias
plotTree(tree_solitarias, fsize=1, lwd=1)


#filogenia especies com socialidade media
comparasion_socialidade_media<-name.check(tree,especies_socialidade_media,data.names=especies_socialidade_media)
comparasion_socialidade_media
comparasion_socialidade_media$tree_not_data
tree_socialidade_media<-drop.tip(tree,comparasion_socialidade_media$tree_not_data)
tree_socialidade_media
plotTree(tree_socialidade_media, fsize=1, lwd=1)


#filogenia especies com sociais
comparasion_sociais<-name.check(tree,especies_sociais,data.names=especies_sociais)
comparasion_sociais
comparasion_sociais$tree_not_data
tree_sociais<-drop.tip(tree,comparasion_sociais$tree_not_data)
tree_sociais
plotTree(tree_sociais, fsize=1, lwd=1)



dev.off()

#arvore inteira
obj1<-ltt(tree,show.tree=TRUE,log.lineages=T,col="red",lwd=2,las=1,xaxt = "n")
axisPhylo()

#solitarias
obj2<-ltt(tree_solitarias,show.tree=TRUE,log.lineages=T,col="black",lwd=2,las=1,xaxt = "n")
axisPhylo()

#socialidade_media
obj3=ltt(tree_socialidade_media,show.tree=TRUE,log.lineages=T,col="green",lwd=2,las=1,xaxt = "n")
axisPhylo()

#sociais
obj4=ltt(tree_sociais,show.tree=TRUE,log.lineages=T,col="yellow",lwd=2,las=1,xaxt = "n")
axisPhylo()


######LTTs

#arvore interira 
obj1<-ltt(tree,show.tree=TRUE,log.lineages=T,col="red",lwd=3,las=1,xaxt = "n")
axisPhylo()


#cada um dos estados 
obj2<-ltt(tree_solitarias,log.lineages=T,col="black",lwd=3,las=1,xaxt = "n")
obj3<-ltt(tree_socialidade_media,log.lineages=T,add=T,col="green",lwd=3)
obj4<-ltt(tree_sociais,log.lineages=T,add=T,col="yellow",lwd=3)


axisPhylo()





#######################################################################
#######################################################################
#############                                                 #########
#############       SINAL FILOGENETICO - ESTATISTICA K        #########
#############                                                 #########
#######################################################################
#######################################################################


#Sinal filogen3tico = meramente um padrAo que mostra se espEcies mais prOximas
#têm valores de atributo mais similares do que espEcies mais distantes. 
#O mEtodos mais comum = estatística K (Blomberg et al 2003) 

#sempre comparamos com o movimento browniano

#K=1 indica que espécies próximas são tão parecidas quanto prevê o modelo Browniano
#K<1 indica sinal filogenético menor do que esperado pelo modelo Browniano
#K>1 indica sinal filogenético maior do que esperado pelo modelo Browniano

# K para tamanho corporal
sinal_tamanho=phylosig(tree,dados$TAMANHO,method="K")

# K para gestação
sinal_gestacao=phylosig(tree,dados$GESTACAO,method="K")



#######################################################################
#######################################################################
#############                                                 #########
#############           TAXAS DE ESPECIACAO E EXTINCAO        #########
#############                                                 #########
#######################################################################
#######################################################################



#####Modelo pure-birth (sem extincao)

#simular mil filogenias atraves desse modelo 
#100 especies
#idade de 10 Ma

allTheTrees <- sim.bd.taxa.age(n = 100, numbsim = 1000, lambda = 0.4, mu = 0,
                               age = 10, mrca = T)

ltt.plot(allTheTrees[[1]], log = "y")
for (i in 2:1000) {
  ltt.lines(allTheTrees[[i]])
}


#######################################################################


#Modelo Birth-death

#AGORA TEMOS EXTINCAO OCORRENDO

#simular mil filogenias atraves desse modelo 

allTheTrees2 <- sim.bd.taxa.age(n = 100, numbsim = 1000, lambda = 2, mu = 1.6,
                                age = 10, mrca = T)

ltt.plot(allTheTrees2[[1]], log = "y")
for (i in 2:1000) {
  ltt.lines(allTheTrees2[[i]])
}


#######################################################################

#simulando as filogenias nesses modelos 

simTree1 <- sim.bd.taxa.age(n = 100, age = 10, numbsim = 1, lambda = 0.4, mu = 0)[[1]]
simTree2 <- sim.bd.taxa.age(n = 100, age = 10, numbsim = 1, lambda = 2, mu = 1.6)[[1]]

par(mfcol = c(1, 2))
plot(simTree1, main = "Pure Birth")
plot(simTree2, main = "Birth-death")



#######################################################################

### calulando especiacao e extincao em nossa filogenia 
#comparando entre modelos pure-birth e birth-death


#lambda= especiacao (por linhagem por milhao de anos)
#ex: se lambda=0.2 isso significa que a cada 1 Ma cada linhagem vai gerar 0.2 de uma especie 
#nova. Desta forma, em 5 Ma teremos uma especie nova sendo criada a cada linhagem

#Mu= extincao 


### Yule (pure-birth -- somente especiação)
modelo.pb<-make.yule(tree)
param.pb<-find.mle(modelo.pb,x.init=0.1) 
#x.init é um valor arbitrário para iniciar o otimização

param.pb

param.pb$par #lambda=especiacao



### Modelo birth-death (especiação + extinção)
modelo.bd<-make.bd(tree)
param.bd<-find.mle(modelo.bd,x.init=c(0.1,0.05))

param.bd

param.bd$par#lambda=especiacao, mu=extincao


dev.off()


#MCMC.
# tambem podemos rodar analises bayesianas para estimar os parâmetros de
#diversificação usando a distribuição posterior probabilidades.

#A estatística bayesiana é uma abordagem estatística que lida com a incerteza por
#meio da atualização contínua de probabilidades à medida que novos dados são observados. 

bd.amostras <- mcmc(modelo.bd, param.bd$par, nsteps = 1e+05, lower = c(0, 0),
                    upper = c(Inf,Inf), w = c(0.1, 0.1), fail.value = -Inf,
                    print.every = 10000)
# visualizar distribuição
postSamples<-bd.amostras[c("lambda", "mu")]
par(mfrow=c(1,1),mar=c(5,4,2,2))
profiles.plot(postSamples,col.line=c("red", "blue"),las=1,legend ="topright")






#######################################################################
#######################################################################
#############                                                 #########
#############  TRANSICOES ENTRE ESTADOS AO LONGO DA EVOLUCAO  #########
#############                                                 #########
#######################################################################
#######################################################################


dieta_cat<-dados$DIETA_CATEGORIA
names(dieta_cat)=rownames(dados)
dieta_cat


## fit ARD model
fitARD<-fitMk(tree,dieta_cat,model="ARD",pi="fitzjohn")
fitARD
#vai demorar alguns minutos


## create plot
plot(fitARD,color=TRUE,lwd=3)
title(main="Mudança de estados ao longo da evolução",
      font.main=3,line=-1)


#save.image("parte_1.Rdata")

